@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 
 import itertools
+from warnings import warn
 
 import networkx as nx
 
@@ -405,7 +406,6 @@ class DAG(nx.DiGraph):
                         independencies.add_assertions(
                             [start, d_seperated_variables, observed]
                         )
-
         independencies.reduce()
 
         if not latex:
@@ -647,14 +647,16 @@ class DAG(nx.DiGraph):
             active_trails[start] = active_nodes
         return active_trails
 
-    def _get_ancestors_of(self, obs_nodes_list):
+    def _get_ancestors_of(self, nodes):
         """
         Returns a dictionary of all ancestors of all the observed nodes including the
         node itself.
+
         Parameters
         ----------
-        obs_nodes_list: string, list-type
+        nodes: string, list-type
             name of all the observed nodes
+
         Examples
         --------
         >>> from pgmpy.base import DAG
@@ -665,15 +667,15 @@ class DAG(nx.DiGraph):
         >>> model._get_ancestors_of(['G', 'I'])
         {'D', 'G', 'I'}
         """
-        if not isinstance(obs_nodes_list, (list, tuple)):
-            obs_nodes_list = [obs_nodes_list]
+        if not isinstance(nodes, (list, tuple)):
+            nodes = [nodes]
 
-        for node in obs_nodes_list:
+        for node in nodes:
             if node not in self.nodes():
                 raise ValueError(f"Node {node} not in not in graph")
 
         ancestors_list = set()
-        nodes_list = set(obs_nodes_list)
+        nodes_list = set(nodes)
         while nodes_list:
             node = nodes_list.pop()
             if node not in ancestors_list:
@@ -681,6 +683,20 @@ class DAG(nx.DiGraph):
             ancestors_list.add(node)
         return ancestors_list
 
+    def to_pdag(self):
+        """
+        Returns the PDAG (the equivalence class of DAG; also known as CPDAG) of the DAG.
+
+        Returns
+        -------
+        PDAG: An instance of pgmpy.base.PDAG.
+
+        Examples
+        --------
+
+        """
+        pass
+
     def do(self, node):
         """
         Applies the do operator to the graph and returns a new DAG with the transformed graph.
@@ -720,3 +736,162 @@ class DAG(nx.DiGraph):
         for parent in parents:
             dag_do_x.remove_edge(parent, node)
         return dag_do_x
+
+    def get_ancestral_graph(self, nodes):
+        """
+        Returns the ancestral graph of the given `nodes`. The ancestral graph only
+        contains the nodes which are ancestors of atleast one of the variables in 
+        node.
+
+        Parameters
+        ----------
+        node: iterable
+            List of nodes whose ancestral graph needs to be computed.
+
+        Returns
+        -------
+        pgmpy.base.DAG instance: The ancestral graph.
+
+        Examples
+        --------
+        >>> from pgmpy.base import DAG
+        >>> dag = DAG([('A', 'C'), ('B', 'C'), ('D', 'A'), ('D', 'B')])
+        >>> anc_dag = dag.get_ancestral_graph(nodes=['A', 'B'])
+        >>> anc_dag.edges()
+        [('D', 'A'), ('D', 'B')]
+        """
+        return self.subgraph(nodes=self._get_ancestors_of(nodes=nodes))
+
+
+class PDAG(nx.DiGraph):
+    """
+    Class for representing PDAGs (also known as CPDAG). PDAGs are the equivance classes of
+    DAGs and contain both directed and undirected edges.
+
+    **Note: In this class, undirected edges are represented using two edges in both direction i.e.
+    an undirected edge between X - Y is represented using X -> Y and X <- Y.
+    """
+
+    def __init__(self, directed_ebunch=[], undirected_ebunch=[]):
+        """
+        Initializes a PDAG class.
+
+        Parameters
+        ----------
+        directed_ebunch: list, array-like of 2-tuples
+            List of directed edges in the PDAG.
+
+        undirected_ebunch: list, array-like of 2-tuples
+            List of undirected edges in the PDAG.
+
+        Returns
+        -------
+        An instance of the PDAG object.
+
+        Examples
+        --------
+        """
+        super(PDAG, self).__init__(
+            directed_ebunch
+            + undirected_ebunch
+            + [(Y, X) for (X, Y) in undirected_ebunch]
+        )
+        self.directed_edges = set(directed_ebunch)
+        self.undirected_edges = set(undirected_ebunch)
+        # TODO: Fix the cycle issue
+        # import pdb; pdb.set_trace()
+        # try:
+        #     # Filter out undirected edges as they also form a cycle in
+        #     # themself when represented using directed edges.
+        #     cycles = filter(lambda t: len(t) > 2, nx.simple_cycles(self))
+        #     if cycles:
+        #         out_str = "Cycles are not allowed in a PDAG. "
+        #         out_str += "The following path forms a loop: "
+        #         out_str += "".join(["({u},{v}) ".format(u=u, v=v) for (u, v) in cycles])
+        #         raise ValueError(out_str)
+        # except nx.NetworkXNoCycle:
+        #     pass
+
+    def copy(self):
+        """
+        Returns a copy of the object instance.
+
+        Returns
+        -------
+        PDAG instance: Returns a copy of self.
+        """
+        return PDAG(
+            directed_ebunch=list(self.directed_edges.copy()),
+            undirected_ebunch=list(self.undirected_edges.copy()),
+        )
+
+    def to_dag(self, required_edges=[]):
+        """
+        Returns one possible DAG which is represented using the PDAG.
+
+        Parameters
+        ----------
+        required_edges: list, array-like of 2-tuples
+            The list of edges that should be included in the DAG.
+
+        Returns
+        -------
+        Returns an instance of DAG.
+
+        Examples
+        --------
+
+        """
+        # Add required edges if it doesn't form a new v-structure or an opposite edge
+        # is already present in the network.
+        dag = DAG()
+        # Add all the nodes and the directed edges
+        dag.add_nodes_from(self.nodes())
+        dag.add_edges_from(self.directed_edges)
+
+        pdag = self.copy()
+        while pdag.number_of_nodes() > 0:
+            # find node with (1) no directed outgoing edges and
+            #                (2) the set of undirecte neighbors is either empty or
+            #                    undirected neighbors + parents of X are a clique
+            found = False
+            for X in pdag.nodes():
+                directed_outgoing_edges = set(pdag.successors(X)) - set(
+                    pdag.predecessors(X)
+                )
+                undirected_neighbors = set(pdag.successors(X)) & set(
+                    pdag.predecessors(X)
+                )
+                neighbors_are_clique = all(
+                    (
+                        pdag.has_edge(Y, Z)
+                        for Z in pdag.predecessors(X)
+                        for Y in undirected_neighbors
+                        if not Y == Z
+                    )
+                )
+
+                if not directed_outgoing_edges and (
+                    not undirected_neighbors or neighbors_are_clique
+                ):
+                    found = True
+                    # add all edges of X as outgoing edges to dag
+                    for Y in pdag.predecessors(X):
+                        dag.add_edge(Y, X)
+                    pdag.remove_node(X)
+                    break
+
+            if not found:
+                warn(
+                    "PDAG has no faithful extension (= no oriented DAG with the "
+                    + "same v-structures as PDAG). Remaining undirected PDAG edges "
+                    + "oriented arbitrarily."
+                )
+                for X, Y in pdag.edges():
+                    if not dag.has_edge(Y, X):
+                        try:
+                            dag.add_edge(X, Y)
+                        except ValueError:
+                            pass
+                break
+        return dag
