@@ -15,6 +15,7 @@ from pgmpy.inference.EliminationOrder import (
     MinWeight,
 )
 from pgmpy.models import JunctionTree, BayesianModel
+from pgmpy.global_vars import SHOW_PROGRESS
 
 
 class VariableElimination(Inference):
@@ -162,13 +163,13 @@ class VariableElimination(Inference):
         )
 
         # Step 3: Run variable elimination
-        if show_progress:
+        if show_progress and SHOW_PROGRESS:
             pbar = tqdm(elimination_order)
         else:
             pbar = elimination_order
 
         for var in pbar:
-            if show_progress:
+            if show_progress and SHOW_PROGRESS:
                 pbar.set_description(f"Eliminating: {var}")
             # Removing all the factors containing the variables which are
             # eliminated (as all the factors should be considered only once)
