@@ -541,7 +541,7 @@ class BayesianModel(DAG):
         >>> train_data = values[:800]
         >>> predict_data = values[800:]
         >>> model = BayesianModel([('A', 'B'), ('C', 'B'), ('C', 'D'), ('B', 'E')])
-        >>> model.fit(values)
+        >>> model.fit(train_data)
         >>> predict_data = predict_data.copy()
         >>> predict_data.drop('E', axis=1, inplace=True)
         >>> y_pred = model.predict(predict_data)
@@ -783,5 +783,5 @@ class BayesianModel(DAG):
         for child_node in children:
             blanket_nodes.extend(self.get_parents(child_node))
         blanket_nodes = set(blanket_nodes)
-        blanket_nodes.remove(node)
+        blanket_nodes.discard(node)
         return list(blanket_nodes)
