@@ -10,6 +10,7 @@ from pgmpy.inference import Inference
 from pgmpy.models import BayesianModel, MarkovChain, MarkovModel
 from pgmpy.utils.mathext import sample_discrete
 from pgmpy.sampling import _return_samples
+from pgmpy.global_vars import SHOW_PROGRESS
 
 
 State = namedtuple("State", ["var", "state"])
@@ -34,7 +35,9 @@ class BayesianModelSampling(Inference):
         self.topological_order = list(nx.topological_sort(model))
         super(BayesianModelSampling, self).__init__(model)
 
-    def forward_sample(self, size=1, return_type="dataframe"):
+    def forward_sample(
+        self, size=1, return_type="dataframe", seed=None, show_progress=True
+    ):
         """
         Generates sample(s) from joint distribution of the bayesian network.
 
@@ -73,9 +76,15 @@ class BayesianModelSampling(Inference):
         types = [(var_name, "int") for var_name in self.topological_order]
         sampled = np.zeros(size, dtype=types).view(np.recarray)
 
-        pbar = tqdm(self.topological_order)
+        if show_progress and SHOW_PROGRESS:
+            pbar = tqdm(self.topological_order)
+        else:
+            pbar = self.topological_order
+
         for node in pbar:
-            pbar.set_description(f"Generating for node: {node}")
+            if show_progress and SHOW_PROGRESS:
+                pbar.set_description(f"Generating for node: {node}")
+
             cpd = self.model.get_cpds(node)
             states = range(self.cardinality[node])
             evidence = cpd.variables[:0:-1]
@@ -85,7 +94,7 @@ class BayesianModelSampling(Inference):
                 weights = list(map(lambda t: cached_values[tuple(t)], evidence.T))
             else:
                 weights = cpd.values
-            sampled[node] = sample_discrete(states, weights, size)
+            sampled[node] = sample_discrete(states, weights, size, seed=seed)
 
         return _return_samples(return_type, sampled, self.state_names_map)
 
@@ -104,7 +113,14 @@ class BayesianModelSampling(Inference):
 
         return cached_values
 
-    def rejection_sample(self, evidence=[], size=1, return_type="dataframe"):
+    def rejection_sample(
+        self,
+        evidence=[],
+        size=1,
+        return_type="dataframe",
+        seed=None,
+        show_progress=True,
+    ):
         """
         Generates sample(s) from joint distribution of the bayesian network,
         given the evidence.
@@ -152,7 +168,7 @@ class BayesianModelSampling(Inference):
 
         # If no evidence is given, it is equivalent to forward sampling.
         if len(evidence) == 0:
-            return self.forward_sample(size)
+            return self.forward_sample(size, seed=seed)
 
         # Setup array to be returned
         types = [(var_name, "int") for var_name in self.topological_order]
@@ -163,10 +179,12 @@ class BayesianModelSampling(Inference):
         # Do the sampling by generating samples from forward sampling and rejecting the
         # samples which do not match our evidence. Keep doing until we have enough
         # samples.
-        pbar = tqdm(total=size)
+        if show_progress and SHOW_PROGRESS:
+            pbar = tqdm(total=size)
+
         while i < size:
             _size = int(((size - i) / prob) * 1.5)
-            _sampled = self.forward_sample(_size, "recarray")
+            _sampled = self.forward_sample(_size, "recarray", seed=seed)
 
             for evid in evidence:
                 _sampled = _sampled[_sampled[evid[0]] == evid[1]]
@@ -175,13 +193,19 @@ class BayesianModelSampling(Inference):
             sampled = np.append(sampled, _sampled)[:size]
 
             i += len(_sampled)
-            pbar.update(len(_sampled))
-        pbar.close()
+
+            if show_progress and SHOW_PROGRESS:
+                pbar.update(len(_sampled))
+
+        if show_progress and SHOW_PROGRESS:
+            pbar.close()
 
         # Post process: Correct return type and replace state numbers with names.
         return _return_samples(return_type, sampled, self.state_names_map)
 
-    def likelihood_weighted_sample(self, evidence=[], size=1, return_type="dataframe"):
+    def likelihood_weighted_sample(
+        self, evidence=[], size=1, return_type="dataframe", seed=None
+    ):
         """
         Generates weighted sample(s) from joint distribution of the bayesian
         network, that comply with the given evidence.
@@ -192,8 +216,10 @@ class BayesianModelSampling(Inference):
         ----------
         evidence: list of `pgmpy.factor.State` namedtuples
             None if no evidence
+
         size: int
             size of sample to be generated
+
         return_type: string (dataframe | recarray)
             Return type for samples, either of 'dataframe' or 'recarray'.
             Defaults to 'dataframe'
@@ -252,14 +278,14 @@ class BayesianModelSampling(Inference):
                     for i in range(size):
                         sampled["_weight"][i] *= weights[i][evidence_dict[node]]
                 else:
-                    sampled[node] = sample_discrete(states, weights)
+                    sampled[node] = sample_discrete(states, weights, size, seed=seed)
             else:
                 if node in evidence_dict:
                     sampled[node] = evidence_dict[node]
                     for i in range(size):
                         sampled["_weight"][i] *= cpd.values[evidence_dict[node]]
                 else:
-                    sampled[node] = sample_discrete(states, cpd.values, size)
+                    sampled[node] = sample_discrete(states, cpd.values, size, seed=seed)
 
         # Postprocess the samples: Correct return type and change state numbers to names
         return _return_samples(return_type, sampled, self.state_names_map)
@@ -277,6 +303,7 @@ class GibbsSampling(MarkovChain):
     Examples
     --------
     Initialization from a BayesianModel object:
+
     >>> from pgmpy.factors.discrete import TabularCPD
     >>> from pgmpy.models import BayesianModel
     >>> intel_cpd = TabularCPD('intel', 2, [[0.7], [0.3]])
@@ -287,7 +314,6 @@ class GibbsSampling(MarkovChain):
     >>> student.add_cpds(intel_cpd, sat_cpd)
     >>> from pgmpy.sampling import GibbsSampling
     >>> gibbs_chain = GibbsSampling(student)
-    Sample from it:
     >>> gibbs_chain.sample(size=3)
        intel  sat
     0      0    0
@@ -327,7 +353,7 @@ class GibbsSampling(MarkovChain):
             scope = set(prod_cpd.scope())
             for tup in itertools.product(*[range(card) for card in other_cards]):
                 states = [State(v, s) for v, s in zip(other_vars, tup) if v in scope]
-                prod_cpd_reduced = prod_cpd.reduce(states, inplace=False)
+                prod_cpd_reduced = prod_cpd.to_factor().reduce(states, inplace=False)
                 kernel[tup] = prod_cpd_reduced.values / sum(prod_cpd_reduced.values)
             self.transition_models[var] = kernel
 
@@ -373,7 +399,7 @@ class GibbsSampling(MarkovChain):
                 kernel[tup] = reduced_factor.values / sum(reduced_factor.values)
             self.transition_models[var] = kernel
 
-    def sample(self, start_state=None, size=1, return_type="dataframe"):
+    def sample(self, start_state=None, size=1, return_type="dataframe", seed=None):
         """
         Sample from the Markov Chain.
 
@@ -416,20 +442,21 @@ class GibbsSampling(MarkovChain):
 
         types = [(var_name, "int") for var_name in self.variables]
         sampled = np.zeros(size, dtype=types).view(np.recarray)
-        sampled[0] = tuple([st for var, st in self.state])
+        sampled[0] = tuple(st for var, st in self.state)
         for i in tqdm(range(size - 1)):
             for j, (var, st) in enumerate(self.state):
                 other_st = tuple(st for v, st in self.state if var != v)
                 next_st = sample_discrete(
                     list(range(self.cardinalities[var])),
                     self.transition_models[var][other_st],
+                    seed=seed,
                 )[0]
                 self.state[j] = State(var, next_st)
-            sampled[i + 1] = tuple([st for var, st in self.state])
+            sampled[i + 1] = tuple(st for var, st in self.state)
 
         return _return_samples(return_type, sampled)
 
-    def generate_sample(self, start_state=None, size=1):
+    def generate_sample(self, start_state=None, size=1, seed=None):
         """
         Generator version of self.sample
 
@@ -464,6 +491,7 @@ class GibbsSampling(MarkovChain):
                 next_st = sample_discrete(
                     list(range(self.cardinalities[var])),
                     self.transition_models[var][other_st],
+                    seed=seed,
                 )[0]
                 self.state[j] = State(var, next_st)
             yield self.state[:]
